@@ -11,6 +11,7 @@ mod group;
 mod private_channel;
 mod reaction;
 mod reaction_type;
+mod stage_instance;
 mod text_channel;
 mod video_quality_mode;
 mod voice_channel;
@@ -21,8 +22,8 @@ pub use self::{
     attachment::Attachment, category_channel::CategoryChannel, channel_mention::ChannelMention,
     channel_type::ChannelType, followed_channel::FollowedChannel, group::Group, message::Message,
     private_channel::PrivateChannel, reaction::Reaction, reaction_type::ReactionType,
-    text_channel::TextChannel, video_quality_mode::VideoQualityMode, voice_channel::VoiceChannel,
-    webhook::Webhook, webhook_type::WebhookType,
+    stage_instance::StageInstance, text_channel::TextChannel, video_quality_mode::VideoQualityMode,
+    voice_channel::VoiceChannel, webhook::Webhook, webhook_type::WebhookType,
 };
 
 use crate::id::{ChannelId, GuildId, MessageId};
@@ -57,7 +58,7 @@ pub enum Channel {
 
 impl Channel {
     /// Return the ID of the inner channel.
-    pub fn id(&self) -> ChannelId {
+    pub const fn id(&self) -> ChannelId {
         match self {
             Self::Group(group) => group.id,
             Self::Guild(guild_channel) => guild_channel.id(),
@@ -90,7 +91,7 @@ pub enum GuildChannel {
 
 impl GuildChannel {
     /// Return the guild ID of the inner guild channel.
-    pub fn guild_id(&self) -> Option<GuildId> {
+    pub const fn guild_id(&self) -> Option<GuildId> {
         match self {
             Self::Category(category) => category.guild_id,
             Self::Text(text) => text.guild_id,
@@ -100,7 +101,7 @@ impl GuildChannel {
     }
 
     /// Return the ID of the inner guild channel.
-    pub fn id(&self) -> ChannelId {
+    pub const fn id(&self) -> ChannelId {
         match self {
             Self::Category(category) => category.id,
             Self::Text(text) => text.id,
@@ -492,7 +493,7 @@ mod tests {
         }
     }
 
-    fn private() -> PrivateChannel {
+    const fn private() -> PrivateChannel {
         PrivateChannel {
             id: ChannelId(234),
             last_message_id: None,
